import { mergeObj, MixinPropsFields, MixinStyleFields, ThemeSize, ThemeType } from '../ka-tools/sdk/mixins';

/**
 * overlay 遮罩
 * @description 创建一个遮罩层，用于强调特定的页面元素，并阻止用户对遮罩下层的内容进行操作，一般用于弹窗场景
 * @property {Boolean}			show		是否显示遮罩（默认 false ）
 * @property {String | Number}	zIndex		zIndex 层级（默认 10070 ）
 * @property {String | Number}	duration	动画时长，单位毫秒（默认 300 ）
 * @property {String | Number}	opacity		不透明度值，当做rgba的第四个参数 （默认 0.5 ）
 * @event {Function} click 点击遮罩发送事件
 */
export interface KaOverlayProps {
  show: boolean;
  zIndex: string | number;
  duration: string | number;
  opacity: string | number;
}

export const DefaultKaOverlayData: KaOverlayProps = {
  show: false,
  zIndex: 10070,
  duration: 300,
  opacity: 0.5,
};

export function useDefaultOverlay(data: KaOverlayProps) {
  mergeObj(DefaultKaOverlayData, data);
}

/**
 * toast 消息提示
 * @description 此组件表现形式类似uni的uni.showToastAPI，但也有不同的地方。
 * @property {Boolean}		show		是否显示该组件 （默认 false）
 * @property {String | Number}	zIndex		toast展示时的zIndex值 (默认 10090 )
 * @property {String | Number}  duration	展示时间，单位ms （默认 2000 ）
 * @property {Boolean}		loading		是否加载中 （默认 false ）
 * @property {String | Number}	message		显示的文字内容
 * @property {String}			icon		图标，或者绝对路径的图片
 * @property {String}			type		主题类型 （默认 default）
 * @property {Boolean}		overlay		是否显示透明遮罩，防止点击穿透 （默认 false ）
 * @property {String}			position	位置 （默认 'center' ）
 * @property {Function}		complete	执行完后的回调函数
 * @property {Object}			_style	组件的样式，对象形式
 * @event {Function} show 显示toast，如需一进入页面就显示toast，请在onReady生命周期调用
 */
export interface KaToastProps {
  show?: boolean;
  zIndex?: string | number;
  duration?: number;
  loading?: boolean;
  message?: string;
  icon?: string;
  type?: ThemeType;
  overlay?: boolean;
  position?: 'center' | 'top' | 'bottom';
  complete?: () => {};
}

export const DefaultKaToastData: KaToastProps = {
  show: false,
  zIndex: 1090,
  duration: 2000,
  type: ThemeType.default,
  position: 'center',
};

export function useDefaultToast(data: KaToastProps) {
  mergeObj(DefaultKaToastData, data);
}
