import { CSSProperties, SVGAttributes } from 'vue';
import { $ka } from '../main';

export interface MixinStyleFields extends CSSProperties {}

export interface MixinPropsFields<T> {
  _class?: string | string[];
  _style?: MixinStyleFields;
  _useData?: T;
}

export enum ThemeType {
  default = 'default',
  error = 'error',
  warning = 'warning',
  primary = 'primary',
  success = 'success',
  loading = 'loading',
}

export enum ThemeSize {
  mini = 10,
  small = 12,
  normal = 14,
  large = 16,
}

// 阻止事件冒泡
export function preventEvent(e: any) {
  e && typeof e.stopPropagation === 'function' && e.stopPropagation();
}
// 空操作
export function noop(e: any) {
  preventEvent(e);
}

// 保存设备系统参数
export const deviceSystemData = $ka.sys();

/**
 * 类型转换
 * @param data
 * @returns
 */
export function useToNumber(data: string | number | undefined | null): number {
  if (typeof data === 'string') {
    return Number(data);
  } else if (data === null || data === undefined) {
    return 0;
  } else {
    return data;
  }
}

/**
 * 动态设置属性
 * @param oldData
 * @param newData
 */
export function mergeObj<T, K extends keyof T>(oldData: T, newData: Partial<Pick<T, K>>) {
  for (const key in newData) {
    if (newData.hasOwnProperty(key)) {
      (oldData as any)[key] = newData[key];
    }
  }
}
